
#if !defined(ptf_bookmark_h)
#define ptf_bookmark_h

#include "ptf_file.h"

//! Create a new bookmark for a given, open, ptf_file_handle.  Returns the record ref of the newly added
//! bookmark record.
//! \param file The file handle to which we add the bookmark.
//! \param bookmark Bookmark data to add.
//! \param ref Record ref of the newly added bookmark.
//! \return ptf_err status.
PTF_API ptf_err ptf_file_create_bookmark( ptf_file_handle file, ptf_bookmark const * bookmark, ptf_fixed_ref * ref );

//! Remove the designated bookmark from a given, open, ptf_file_handle.
//! \param file The file handle to which we add the bookmark.
//! \param ref Record ref of the bookmark record to be removed.
//! \return ptf_err status.
PTF_API ptf_err ptf_file_remove_bookmark( ptf_file_handle file, ptf_fixed_ref const &ref );

//! Retrieve the bookmark data for the given record ref.
//! \param file The file handle if the file to be queried.
//! \param ref Record ref of the bookmark to retrieve.
//! \param bookmark Retrieved bookmark data.
//! \return ptf_err status.
PTF_API ptf_err ptf_file_get_bookmark( ptf_file_handle file, ptf_fixed_ref const &ref, ptf_bookmark * bookmark );

//! Modify the bookmark data for the given record ref.  This function replaces the contents of the designated
//! bookmark record in the ptf file.
//! \param file The file handle of the file to be modified.
//! \param ref Record ref of the bookmark to be modified.
//! \param bookmark New bookmark data that will replace the existing data.
//! \return ptf_err status.
PTF_API ptf_err ptf_file_set_bookmark( ptf_file_handle file, ptf_fixed_ref const &ref, ptf_bookmark const * bookmark );

#endif  //  ptf_bookmark_h
